@@ -1,12 +1,12 @@
 from typing import Mapping, Sequence, Union
 from pandas import DataFrame
-from roguewave.modeldata.open_remote import open_remote_dataset
+
 from roguewave.spotterapi.spotterapi import get_bulk_wave_data
-from roguewave.interpolate.dataset import interpolate_dataset
+from roguewave.interpolate.dataset import tracks_as_dataset
 from roguewave.modeldata.extract import extract_from_remote_dataset
 from roguewave.interpolate.dataframe import interpolate_dataframe_time
 from roguewave.modeldata.timebase import TimeSlice
-from roguewave.interpolate.geometry import TrackSet
+
 
 # =============================================================================
 def colocate_model_spotter(
@@ -55,11 +55,16 @@ def colocate_model_spotter(
                                   time_slice.end_time,
                                   convert_to_sofar_model_names=True)
 
+    for spotter_id in list(spotters.keys()):
+        # If only one value - pop because we cannot interpolate on 1 value.
+        if spotters[spotter_id].shape[0] <= 2:
+            spotters.pop(spotter_id)
+
     data =  extract_from_remote_dataset( spotters, variable,
                             time_slice,model_name,slice_remotely=slice_remotely,
                                 parallel=parallel, cache_name=cache_name  )
     out = {}
-    for spotter_id in spotter_ids:
+    for spotter_id in spotters:
         s = spotters[spotter_id] # type: DataFrame
         m = data[spotter_id] # type: DataFrame
         if timebase.lower() == 'native':
@@ -77,3 +82,12 @@ def colocate_model_spotter(
             'spotter':s
         }
     return out
+
+
+def colocated_tracks_as_dataset(colocated_data):
+     keys = list(colocated_data.keys())
+     time = colocated_data[keys[0]]['model'].index.values
+
+     model_data = tracks_as_dataset(time, colocated_data, 'model')
+     drifter_data = tracks_as_dataset(time, colocated_data, 'spotter')
+     return drifter_data, model_data
\ No newline at end of file
